@@ -1,5 +1,6 @@
 import os
 import typer
+from typing import Optional
 from lambda_cloud_cli.lambda_api_client import LambdaAPIClient
 from lambda_cloud_cli.config import load_api_key, save_api_key, delete_api_key
 
@@ -43,8 +44,27 @@ def terminate(instance_id: str):
     typer.echo(result)
 
 @app.command(name="launch-instance")
-def launch_instance():
-    typer.echo("This function requires a JSON payload. Add JSON input handling if needed.")
+def launch_instance(
+    region_name: str = typer.Argument(..., help="Lambda region (e.g. us-west-1)"),
+    instance_type: str = typer.Argument(..., help="Instance type (e.g. gpu_1x_a10)"),
+    ssh_key_name: str = typer.Argument(..., help="Your SSH key name"),
+    name: str = typer.Argument("lambda-cli-instance", help="Instance name (default: lambda-cli-instance)"),
+    image_id: Optional[str] = typer.Option(None, help="Optional image ID")
+):
+    """Launch a Lambda Cloud instance with minimal parameters"""
+    payload = {
+        "region_name": region_name,
+        "instance_type_name": instance_type,
+        "ssh_key_names": [ssh_key_name],
+        "name": name
+    }
+
+    if image_id:
+        payload["image"] = {"id": image_id}
+
+    result = get_client().launch_instance(payload)
+    typer.echo("🚀 Launch request sent!")
+    typer.echo(result)
 
 @app.command(name="update-instance-name")
 def update_instance_name(instance_id: str, new_name: str):
